@@ -40,9 +40,7 @@ class CommentMixin:
         )
         get_comments()
         while ((result.get("has_more_comments") and result.get("next_max_id"))
-               or (result.get("has_more_headload_comments") and result.get("next_min_id")))
-               and (True if not amount else len(comments) < amount)):
-                
+               or (result.get("has_more_headload_comments") and result.get("next_min_id"))):
             try:
                 if result.get("has_more_comments"):
                     params = {"max_id": result.get("next_max_id")}
@@ -61,7 +59,7 @@ class CommentMixin:
                 if "Media not found" in str(e):
                     raise MediaNotFound(e, media_id=media_id, **self.last_json)
                 raise e
-            if amount and amount >= len(comments):
+            if amount and len(comments) >= amount:
                 break
         if amount:
             comments = comments[:amount]
